@@ -14,6 +14,12 @@
 # =============================================================================
 #++
 
+begin
+  require 'rubygems'
+  gem "net-ssh", "< 1.99.0"
+rescue LoadError
+end
+
 require 'net/ssh'
 require 'net/sftp/session'
 
