@@ -1,6 +1,6 @@
 #--
 # =============================================================================
-# Copyright (c) 2004, Jamis Buck (jgb3@email.byu.edu)
+# Copyright (c) 2004, Jamis Buck (jamis@37signals.com)
 # All rights reserved.
 #
 # This source file is distributed as part of the Net::SFTP Secure FTP Client
@@ -17,7 +17,7 @@
 module Net ; module SFTP
 
   # The base exception class for the SFTP system.
-  class Exception < ::Exception; end
+  class Exception < RuntimeError; end
 
   # An exception class representing a bug condition.
   class Bug < Exception; end
