@@ -1,6 +1,6 @@
 #--
 # =============================================================================
-# Copyright (c) 2004, Jamis Buck (jgb3@email.byu.edu)
+# Copyright (c) 2004, Jamis Buck (jamis@37signals.com)
 # All rights reserved.
 #
 # This source file is distributed as part of the Net::SFTP Secure FTP Client
@@ -26,9 +26,6 @@ class TC_04_PacketAssistant < TC_03_PacketAssistant
     Net::SFTP::Protocol::V_04::PacketAssistant
   end
 
-  packet :open, [ "a path", 1, 2, "attrs" ],
-    "\0\0\0\6a path\0\0\0\1\0\0\0\2attrs"
-
   packet :rename, [ "old name", "new name", 1 ],
     "\0\0\0\10old name\0\0\0\10new name\0\0\0\1"
 
